@@ -1,4 +1,5 @@
 package CPANPLUS::Internals::Constants::Report;
+use deprecate;
 
 use strict;
 use CPANPLUS::Error;
@@ -14,11 +15,10 @@ use Package::Constants;
 ### for the version
 require CPANPLUS::Internals;
 
-$VERSION    = $CPANPLUS::Internals::VERSION = $CPANPLUS::Internals::VERSION;
+$VERSION = "0.9135";
 @ISA        = qw[Exporter];
 @EXPORT     = Package::Constants->list( __PACKAGE__ );
 
-
 ### OS to regex map ###
 my %OS = (
     Amiga       => 'amigaos',
@@ -347,6 +347,8 @@ use constant REPORT_TOOLCHAIN_VERSIONS
                                     ExtUtils::ParseXS
                                     File::Spec
                                     Module::Build
+                                    Pod::Parser
+                                    Pod::Simple
                                     Test::Harness
                                     Test::More
                                     version
