@@ -1,4 +1,5 @@
 package CPANPLUS::Internals::Search;
+use deprecate;
 
 use strict;
 
@@ -13,6 +14,9 @@ use File::Spec;
 use Params::Check               qw[check allow];
 use Locale::Maketext::Simple    Class => 'CPANPLUS', Style => 'gettext';
 
+use vars qw[$VERSION];
+$VERSION = "0.9135";
+
 $Params::Check::VERBOSE = 1;
 
 =pod
